

"use client";
import { useState} from "react";
import { useRouter } from "next/navigation";
import Image from "next/image";

import { useApiKey } from "../context/ApiKeyContext"; // Import the hook

const TitleTypeSelector = () => {
//   const { apiKey } = useContext(FirebaseConfigContext); // 🔑 Get API Key from context
  const [selectedType, setSelectedType] = useState("Blog Article");
  const [titleKeyword, setTitleKeyword] = useState("");
  const router = useRouter();
  const apiKey = useApiKey(); // Get API key from context
  const [loading, setLoading] = useState(false);


  const handleSelection = (event: React.ChangeEvent<HTMLSelectElement>) => {
    setSelectedType(event.target.value);
  };

  const handleInputChange = (event: React.ChangeEvent<HTMLInputElement>) => {
    setTitleKeyword(event.target.value);
  };

  const handleGenerate = async () => {
    if (!titleKeyword.trim()) return;

    // 🚀 Send request to OpenAI API
    try {
        const response = await fetch("/api/generate-title", {
          method: "POST",
          headers: { "Content-Type": "application/json" },
          body: JSON.stringify({ titleKeyword: titleKeyword, type: selectedType, apiKey }),
          
        });
      
        console.log("API response:", response.body);  // Log response for more information
        const data = await response.json();
        console.log("API response data:", data);  // Log data to check the returned content
      
        if (!response.ok) {
          throw new Error(`API error: ${data.error || response.statusText}`);
        }
      
        // router.push(`/ArticleGenerator?content=${encodeURIComponent(data.content)}`);
          // Push content into the same page via query params
      router.push(`?content=${encodeURIComponent(data.content)}`);
      } catch (error) {
        console.error("❌ Error generating article:", error);
      }
      
  };

  return (
    <div className="col-lg-4 col-12 mb-4 mb-lg-0">
      <div className="custom-block bg-white shadow-lg p-4 rounded-3">
        <h4 className="mb-3 text-primary">Title Generator</h4>
        <p className="text-muted">Enter keywords, then select the title type.</p>

        {/* Title & Keyword Input */}
        <input 
          type="text" 
          className="form-control mb-3"
          placeholder="e.g., Digital Marketing, social media"
          value={titleKeyword}
          onChange={handleInputChange}
        />

        {/* Dropdown Selector */}
        <select className="form-select mb-3" onChange={handleSelection} value={selectedType}>
  <option value="Blog Article">📝 Blog Article</option>
  <option value="YouTube Video">🎥 YouTube Video</option>
  <option value="How-To Guide">📖 How-To Guide</option>
  <option value="Question-Based Titles">❓ Question-Based Titles</option>
  <option value="Comparison Titles">⚖️ Comparison Titles</option>
  <option value="News Headlines">📰 News Headlines</option>
</select>


        {/* Generate Button */}
<button 
  className={`btn btn-${titleKeyword.trim() ? "success" : "secondary"} w-100`}
  onClick={() => {
    setLoading(true); // Start loading
    handleGenerate(); // Call the generate function
    setTimeout(() => setLoading(false), 8000); // Set timeout for 6 seconds
  }}
  disabled={!titleKeyword.trim() || !apiKey || loading} // Disable if API key is missing or loading
>
  {loading ? "Loading..." : "Generate Titles"}
</button>

        {/* Image */}
        <Image
          src="/images/topics/undraw_Remote_design_team_re_urdx.png"
          width={800}
          height={500}
          className="custom-block-image img-fluid mt-3 rounded"
          alt="Article Type"
          priority
        />
      </div>
    </div>
  );
};

export default TitleTypeSelector;
